/** 
 * @file yfrobot
 * @brief YFROBOT's sensors Mind+ library.
 * @n This is a MindPlus graphics programming extension for YFROBOT's module.
 * 
 * @copyright    YFROBOT,2023
 * @copyright    MIT Lesser General Public License
 * 
 * @author [email](yfrobot@qq.com)
 * @date  2023-06-01
*/

enum ONOFF {
    //% blockId="SW_ON" block="On"
    true,
    //% blockId="SW_OFF" block="Off"
    false
}

//% color="#18bfc7" iconWidth=50 iconHeight=40
namespace FPM {

    //% block="Finger Identify initliallize Software RX[rx] TX[tx]" blockType="command"
    //% rx.shadow="dropdown" rx.options="SSRXD"
    //% tx.shadow="dropdown" tx.options="SSTXD"
    export function init(parameter: any, block: any) {
        let rxpin = parameter.rx.code;
        let txpin = parameter.tx.code;
        Generator.addInclude("include_fpm", `#include "yfrobot_fpm383.h"`);
        // Generator.addObject("fpm_SoftwareSerial_Object", `SoftwareSerial`, `mySerial(${rxpin}, ${txpin}); `);
        Generator.addObject("fpm_YFROBOTFPM383_Object", `YFROBOTFPM383`, `fpm(${rxpin}, ${txpin}); `);
        Generator.addSetup(`initSetup_init`, `Serial.println(fpm.getChipSN());`);
    }

    //% block="Finger Identify Verify and get ID, no finger [SW] " blockType="reporter"
    //% SW.shadow="dropdown" SW.options="ONOFF" SW.defl="ONOFF.true"
    export function identify(parameter: any, block: any) {
        let sw = parameter.SW.code;
        Generator.addCode(`fpm.identify(${sw})`);
    }

    // //% block="Finger Identify ID: [ID] " blockType="boolean"
    // //% ID.shadow="range"   ID.params.min=0    ID.params.max=49    ID.defl=0
    // export function identifyID(parameter: any, block: any) {
    //     let id = parameter.ID.code;
    //     Generator.addCode(`fpm.identify() == (${id})`);
    // }

    //% block="Finger Identify enroll ID: [ID] Enroll Times [ET]" blockType="reporter"
    //% ID.shadow="range"   ID.params.min=0    ID.params.max=49    ID.defl=0
    //% ET.shadow="range"   ET.params.min=1    ET.params.max=12    ET.defl=4
    export function enroll(parameter: any, block: any) {
        let id = parameter.ID.code;
        let et = parameter.ET.code;
        Generator.addCode(`fpm.enroll(${id},${et})`);
    }

    // //% block="Finger Identify delete ID: [ID]" blockType="command"
    // //% ID.shadow="range"   ID.params.min=0    ID.params.max=49    ID.defl=0
    // export function deleteID(parameter: any, block: any) {
    //     let id = parameter.ID.code;
    //     Generator.addCode(`fpm.deleteID(${id});`);
    // }

    //% block="Finger Identify delete ID: [ID] and return status" blockType="reporter"
    //% ID.shadow="range"   ID.params.min=0    ID.params.max=49    ID.defl=0
    export function deleteID_r(parameter: any, block: any) {
        let id = parameter.ID.code;
        Generator.addCode(`fpm.deleteID(${id})`);
    }

    // //% block="Finger Identify empty" blockType="command"
    // export function empty(parameter: any, block: any) {
    //     Generator.addCode(`fpm.empty();`);
    // }

    //% block="Finger Identify empty and return status" blockType="reporter"
    export function empty_r(parameter: any, block: any) {
        Generator.addCode(`fpm.empty()`);
    }

    //% block="Finger Identify inquiry" blockType="reporter"
    export function inquiry(parameter: any, block: any) {
        Generator.addCode(`fpm.inquiry()`);
    }
}
